﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using FlexChartVsC1Chart.Resources;

namespace FlexChartVsC1Chart.Features
{
    public enum FlexChartMode
    {
        Chart, Pie
    }
    public partial class BaseFeature : UserControl
    {
        public FlexChartMode FlexChartMode { get; set; }
        private Timer tFlex;
        private Timer tC1;
        private bool btnFlexHovered, btnC1Hovered;
        public BaseFeature()
        {
            InitializeComponent();
            lblTitleC1.Text = AppResources.C1ChartPanelTitle;
            lblTitleFlex.Text = AppResources.FlexChartPanelTitle;
            btnCopyC1Code.Text = AppResources.Copy;
            btnCopyFlexCode.Text = AppResources.Copy;
            tFlex = new Timer { Interval = 100 };
            tFlex.Tick += tL_Tick;
            tC1 = new Timer { Interval = 100 };
            tC1.Tick += tR_Tick;
        }

        public BaseFeature(FlexChartMode flexChartMode)
        {
            InitializeComponent();
            UpdateChartType(flexChartMode);
        }

        public void UpdateChartType(FlexChartMode flexChartMode)
        {
            this.FlexChartMode = flexChartMode;
            if (FlexChartMode == FlexChartMode.Chart)
            {
                flexPie.Visible = false;
                flexChart.Visible = true;
            }
            else
            {
                flexPie.Visible = true;
                flexChart.Visible = false;
            }
        }

        private void btnCopyFlex_Click(object sender, EventArgs e)
        {
            Clipboard.Clear();
            Clipboard.SetText(tbCodeFlex.Text);
        }

        private void btnCopyC1_Click(object sender, EventArgs e)
        {
            Clipboard.Clear();
            Clipboard.SetText(tbCodeC1.Text);
        }

        private void btnCopyFlex_MouseEnter(object sender, EventArgs e)
        {
            btnFlexHovered = true;
            btnCopyFlexCode.BackgroundImage = FlexChartVsC1Chart.Properties.Resources.btnCopyMouseOn;
            ttCopy.Show(AppResources.CoopyTooltipContent, btnCopyFlexCode, -33, -35);
        }

        private void btnCopyC1_MouseEnter(object sender, EventArgs e)
        {
            btnC1Hovered = true;
            btnCopyC1Code.BackgroundImage = FlexChartVsC1Chart.Properties.Resources.btnCopyMouseOn;
            ttCopy.Show(AppResources.CoopyTooltipContent, btnCopyC1Code, -33, -35);
        }

        private void btnCopyFlex_MouseLeave(object sender, EventArgs e)
        {
            btnFlexHovered = false;
            btnCopyFlexCode.BackgroundImage = FlexChartVsC1Chart.Properties.Resources.btnCopy;
            ttCopy.RemoveAll();
        }

        private void btnCopyC1_MouseLeave(object sender, EventArgs e)
        {
            btnC1Hovered = false;
            btnCopyC1Code.BackgroundImage = FlexChartVsC1Chart.Properties.Resources.btnCopy;
            ttCopy.RemoveAll();
        }

        private void ttCopy_Draw(object sender, DrawToolTipEventArgs e)
        {
            // Draw the custom background.
            e.Graphics.FillRectangle(new SolidBrush(Color.Black), e.Bounds);

            // Draw the custom text.
            // The using block will dispose the StringFormat automatically.
            using (StringFormat sf = new StringFormat())
            {
                sf.FormatFlags = StringFormatFlags.NoClip | StringFormatFlags.NoFontFallback;
                sf.Alignment = StringAlignment.Center;
                sf.LineAlignment = StringAlignment.Center;
                sf.HotkeyPrefix = System.Drawing.Text.HotkeyPrefix.None;
                sf.FormatFlags = StringFormatFlags.NoWrap;
                using (Font f = new Font("Segoe UI", 9, FontStyle.Bold))
                {
                    e.Graphics.DrawString(e.ToolTipText, f,
                        new SolidBrush(Color.White), e.Bounds, sf);
                }
            }
        }

        private void ttCopy_Popup(object sender, PopupEventArgs e)
        {
            e.ToolTipSize = new Size(130, 30);
        }

        private void splitContainer_Resize(object sender, EventArgs e)
        {
            try
            {
                this.splitContainer1.SplitterDistance = this.Width / 2;
            }
            catch { }
        }

        private void tbCode_MouseEnter(object sender, EventArgs e)
        {
            var tb = sender as TextBox;
            if (tb.Name.Contains("Flex"))
                btnCopyFlexCode.Visible = true;
            else if (tb.Name.Contains("C1"))
                btnCopyC1Code.Visible = true;
        }

        private void tbCode_MouseLeave(object sender, EventArgs e)
        {
            var tb = sender as TextBox;
            if (tb.Name.Contains("Flex"))
                tFlex.Start();
            else if (tb.Name.Contains("C1"))
                tC1.Start();

        }

        void tL_Tick(object sender, EventArgs e)
        {
            btnCopyFlexCode.Visible = btnFlexHovered;
            tFlex.Stop();
        }

        void tR_Tick(object sender, EventArgs e)
        {
            btnCopyC1Code.Visible = btnC1Hovered;
            tC1.Stop();
        }
    }
}
