﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using C1.Win.Chart;
using C1.Win.C1Chart;
using FlexChartVsC1Chart.Models;

namespace FlexChartVsC1Chart.Features
{
    public partial class DataLabels : UserControl
    {
        FlexChart flexChart;
        C1Chart c1Chart;

        public DataLabels()
        {
            InitializeComponent();
            baseFeature.UpdateChartType(FlexChartMode.Chart);
            flexChart = baseFeature.flexChart;
            c1Chart = baseFeature.c1Chart;
            SetupFlex();
            SetUpC1();
            SetUpDisplayCode();
        }


        private void SetupFlex()
        {
            flexChart.DataSource = DataSource.CategoricalData;
            flexChart.BindingX = "Name";

            flexChart.Series.Clear();
            flexChart.Series.Add(new Series { Binding = "Sales", Name = "Sales" });
            flexChart.Series.Add(new Series { Binding = "Downloads", Name = "Downloads" });
            flexChart.Series.Add(new Series { Binding = "Expenses", Name = "Expenses" });

            flexChart.ChartType = C1.Chart.ChartType.Column;
            flexChart.Legend.Position = C1.Chart.Position.Bottom;

            //DataLabels
            flexChart.DataLabel.Content = "{y}";
            flexChart.DataLabel.Position = C1.Chart.LabelPosition.Top;

            flexChart.AxisX.Title = "Axis X";
            flexChart.AxisY.Title = "Axis Y";

        }

        private void SetUpC1()
        {

            c1Chart.DataSource = DataSource.CategoricalData;
            c1Chart.ChartGroups[0].ChartData.SeriesList.Clear();

            var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            salesSeries.X.DataField = "Name";
            salesSeries.Y.DataField = "Sales";
            salesSeries.Label = "Sales";

            var downloadsSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            downloadsSeries.X.DataField = "Name";
            downloadsSeries.Y.DataField = "Downloads";
            downloadsSeries.Label = "Downloads";

            var expenseSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            expenseSeries.X.DataField = "Name";
            expenseSeries.Y.DataField = "Expenses";
            expenseSeries.Label = "Expenses";

            c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.Bar;

            //DataLabels
            ChartDataSeriesCollection sc = c1Chart.ChartGroups[0].ChartData.SeriesList;
            for (int i = 0; i <= sc.Count - 1; i++)
            {
                var dataLabel = sc[i].DataLabel;
                dataLabel.Visible = true;
                dataLabel.Compass = LabelCompassEnum.North;
                dataLabel.Text = "{#YVAL}";
            }

            c1Chart.Legend.Visible = true;
            c1Chart.Legend.Compass = CompassEnum.South;

        }

        private void SetUpDisplayCode()
        {
            baseFeature.tbCodeFlex.Text = @"
flexChart.DataLabel.Content = ""{y}"";
flexChart.DataLabel.Position = C1.Chart.LabelPosition.Top;";

            baseFeature.tbCodeC1.Text = @"
ChartDataSeriesCollection sc = c1Chart.ChartGroups[0].ChartData.SeriesList;
for (int i = 0; i <= sc.Count - 1; i++)
{
    var dataLabel = sc[i].DataLabel;
    dataLabel.Visible = true;
    dataLabel.Compass = LabelCompassEnum.North;
    dataLabel.Text = ""{#YVAL}"";
}";
        }
    }
}
