﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using C1.Win.Chart;
using C1.Win.C1Chart;
using FlexChartVsC1Chart.Models;
using System.Collections.ObjectModel;

namespace FlexChartVsC1Chart.Features
{
    public partial class DynamicCharts : UserControl
    {
        FlexChart flexChart;
        C1Chart c1Chart;
        Timer timer;
        Random random;
        ObservableCollection<NumericPoint> data;
        C1.Win.C1Chart.ChartDataArray c1ChartData;
        int counter;

        private const int CHART_MAX = 600;
        private const int CHART_MIN = 350;
        public DynamicCharts()
        {
            InitializeComponent();
            timer = new Timer { Interval = 200 };
            random = new Random();
            timer.Tick += timer_Tick;

            baseFeature.UpdateChartType(FlexChartMode.Chart);
            flexChart = baseFeature.flexChart;
            c1Chart = baseFeature.c1Chart;
            //Init Data
            data = new ObservableCollection<NumericPoint>();
            for (int i = 0; i <10; i++)
                data.Add(getItem());

            counter = data.Count;
            SetupFlex();
            SetUpC1();
            SetUpDisplayCode();
            timer.Start();
        }

        private NumericPoint getItem(NumericPoint lastItem = null)
        {
            NumericPoint newPoint = new NumericPoint();
            newPoint.XValue = counter++;
            if (lastItem == null)
            {
                do
                {
                    newPoint.YValue = random.NextDouble() * 500;
                } while (newPoint.YValue < CHART_MIN + 50);

            }
            else
            {
                do
                {
                    newPoint.YValue = Math.Max(400, lastItem.YValue + (random.NextDouble() * 100) - 50) - 1;  
                } while (newPoint.YValue >= CHART_MAX);
            }
            return newPoint;
        }

        void timer_Tick(object sender, EventArgs e)
        {
            var last = data[data.Count - 1];
            var newPoint = getItem(last);

            //For FlexChart
            if (data.Count > 20)
                data.RemoveAt(0);
            data.Add(newPoint);

            //For C1Chart
            if (c1ChartData.Length < 20)
                c1ChartData.Length++;
            c1ChartData[c1ChartData.Length - 1] = new PointF(c1ChartData.Length - 1, (float)newPoint.YValue);

            for (int i = 1; i < c1ChartData.Length; i++)
            {
                PointF p = (PointF)c1ChartData[i];
                p.X--;
                c1ChartData[i - 1] = p;
            }
        }


        private void SetupFlex()
        {
            flexChart.DataSource = data;
            flexChart.BindingX = "XValue";

            flexChart.Series.Clear();
            flexChart.Series.Add(new Series { Binding = "YValue", Name = "S1" });

            flexChart.ChartType = C1.Chart.ChartType.Area;
            flexChart.Legend.Position = C1.Chart.Position.None;

            flexChart.AxisX.Title = "Axis X";
            flexChart.AxisX.Labels = false;
            flexChart.AxisY.Title = "Axis Y";
            flexChart.AxisY.Min = CHART_MIN;
            flexChart.AxisY.Max = CHART_MAX;

        }

        private void SetUpC1()
        {
            c1Chart.DataSource = data;
            c1Chart.ChartGroups[0].ChartData.SeriesList.Clear();
            
            var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            salesSeries.X.DataField = "XValue";
            salesSeries.Y.DataField = "YValue";
            salesSeries.Label = "S1";
            c1Chart.ChartArea.AxisX.Visible = false;
            c1Chart.ChartArea.AxisY.Min = CHART_MIN;
            c1Chart.ChartArea.AxisY.Max = CHART_MAX;
            c1Chart.ChartArea.AxisY.UnitMajor = 50;
            c1ChartData = salesSeries.PointData;
            c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.Area;

        }

        private void SetUpDisplayCode()
        {
            baseFeature.tbCodeFlex.Text = @"
if (data.Count > 20)
    data.RemoveAt(0);
data.Add(newPoint);";

            baseFeature.tbCodeC1.Text = @"
if (c1ChartData.Length < 20)
    c1ChartData.Length++;
c1ChartData[c1ChartData.Length - 1] = new PointF(c1ChartData.Length - 1, (float)newPoint.YValue);

for (int i = 1; i < c1ChartData.Length; i++)
{
    PointF p = (PointF)c1ChartData[i];
    p.X--;
    c1ChartData[i - 1] = p;
}";
        }
    }
}
