﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using C1.Win.Chart;
using System.Drawing.Drawing2D;
using System.Collections.ObjectModel;
using C1.Win.C1Chart;
using FlexChartVsC1Chart.Models;


namespace FlexChartVsC1Chart.Features
{
    public partial class HitTest : UserControl
    {
        FlexChart flexChart;
        C1Chart c1Chart;

        public HitTest()
        {
            InitializeComponent();
            baseFeature.UpdateChartType(FlexChartMode.Chart);
            flexChart = baseFeature.flexChart;
            c1Chart = baseFeature.c1Chart;

            var strLeftTemplate = new StringBuilder();
            var strRightTemplate = new StringBuilder();

            strLeftTemplate.AppendLine("Chart Element:");
            strLeftTemplate.AppendLine("Series Name:");

            strRightTemplate.AppendLine("Name:");
            strRightTemplate.AppendLine("Sales:");
            strRightTemplate.AppendLine("Downloads:");
            strRightTemplate.AppendLine("Expenses:");

            baseFeature.lblFooterC1_Left.Text = baseFeature.lblFooterFlex_Left.Text = strLeftTemplate.ToString();
            baseFeature.lblFooterC1_Right.Text = baseFeature.lblFooterFlex_Right.Text = strRightTemplate.ToString();

            baseFeature.panelFooterContainerC1.Height =baseFeature.panelFooterContainerFlex.Height = 80;

            SetupFlex();
            SetUpC1();
            SetUpDisplayCode();
        }


        private void SetupFlex()
        {
            flexChart.DataSource = DataSource.CategoricalData;
            flexChart.Series.Clear();
            flexChart.BindingX = "Name";

            flexChart.Series.Add(new Series { Binding = "Sales", Name = "Sales" });
            flexChart.Series.Add(new Series { Binding = "Downloads", Name = "Downloads" });
            flexChart.Series.Add(new Series { Binding = "Expenses", Name = "Expenses" });

            flexChart.ChartType = C1.Chart.ChartType.Column;
            flexChart.Legend.Position = C1.Chart.Position.Bottom;

            flexChart.AxisX.Title = "Axis X";
            flexChart.AxisY.Title = "Axis Y";
            flexChart.MouseMove += flexChart_MouseMove;
        }

        void flexChart_MouseMove(object sender, MouseEventArgs e)
        {
            /*The HitTest() method returns a HitTestInfo object 
             that contains information about the specified point*/
            var ht = flexChart.HitTest(e.Location);
            var result = new StringBuilder();
            result.AppendLine(string.Format("Chart element:{0}", ht.ChartElement));
            if (ht.Series != null)
                result.AppendLine(string.Format("Series name:{0}", ht.Series.Name));
            baseFeature.lblFooterFlex_Left.Text = result.ToString();

            var item = ht.Item as CategoricalPoint;
            if (item != null)
            {
                var result2 = new StringBuilder();
                result2.AppendLine(string.Format("Name ={0}", item.Name));
                result2.AppendLine(string.Format("Sales ={0}", item.Sales));
                result2.AppendLine(string.Format("Downloads ={0}", item.Downloads));
                result2.AppendLine(string.Format("Expenses ={0}", item.Expenses));
                baseFeature.lblFooterFlex_Right.Text = result2.ToString();
            }
            else
                baseFeature.lblFooterFlex_Right.Text = string.Empty;
        }

        private void SetUpC1()
        {

            c1Chart.DataSource = DataSource.CategoricalData;
            c1Chart.ChartGroups[0].ChartData.SeriesList.Clear();

            var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            salesSeries.X.DataField = "Name";
            salesSeries.Y.DataField = "Sales";
            salesSeries.Label = "Sales";

            var downloadsSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            downloadsSeries.X.DataField = "Name";
            downloadsSeries.Y.DataField = "Downloads";
            downloadsSeries.Label = "Downloads";

            var expenseSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            expenseSeries.X.DataField = "Name";
            expenseSeries.Y.DataField = "Expenses";
            expenseSeries.Label = "Expenses";

            c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.Bar;
            c1Chart.Legend.Visible = true;
            c1Chart.Legend.Compass = CompassEnum.South;

            c1Chart.MouseMove += c1Chart_MouseMove;
        }

        void c1Chart_MouseMove(object sender, MouseEventArgs e)
        {
            int g = 0, s = -1, p = -1, d = -1;
            const int MIN_DIST = 3;
            CoordinateFocusEnum focus = CoordinateFocusEnum.XandYCoord;
            ChartGroup grp = c1Chart.ChartGroups[g];
            var result1 = new StringBuilder();
            var result2 = new StringBuilder();

            ChartRegionEnum region = c1Chart.ChartRegionFromCoord(e.X, e.Y);
            result1.AppendLine(string.Format("Chart element:{0}", region));

            if (region == ChartRegionEnum.Legend)
            {
                baseFeature.lblFooterC1_Right.Text = String.Empty;
                if (c1Chart.Legend.SeriesFromCoord(e.X, e.Y, ref g, ref s))
                {
                    if (s >= 0)
                    {
                        string name = grp.ChartData[s].Label;
                        result1.AppendLine(string.Format("Series Name:{0}",name));
                    }
                }
            }
            else
            {
                if (grp.CoordToDataIndex(e.X, e.Y, focus, ref s, ref p, ref d))
                {
                    string name = grp.ChartData[s].Label;
                    result1.AppendLine(string.Format("Series Name:{0}", name));
                    if (d < MIN_DIST)
                    {
                        /*Get the Chart DataSource and then
                         * get the Data item at the Point Index 'p'
                        */
                        var ds = c1Chart.DataSource as ObservableCollection<CategoricalPoint>;
                        var item = ds[p];
                        result2.AppendLine(string.Format("Name ={0}", item.Name));
                        result2.AppendLine(string.Format("Sales ={0}", item.Sales));
                        result2.AppendLine(string.Format("Downloads ={0}", item.Downloads));
                        result2.AppendLine(string.Format("Expenses ={0}", item.Expenses));
                        baseFeature.lblFooterC1_Right.Text = result2.ToString();
                    }
                }
            }
            baseFeature.lblFooterC1_Left.Text = result1.ToString();
        }

        private void SetUpDisplayCode()
        {
            baseFeature.tbCodeFlex.Text = @"
void flexChart_MouseMove(object sender, MouseEventArgs e)
{
    /*The HitTest() method returns a HitTestInfo object 
    that contains information about the specified point*/
    var ht = flexChart.HitTest(e.Location);
    var result = new StringBuilder();
    result.AppendLine(string.Format(""Chart element:{0}"", ht.ChartElement));
    if (ht.Series != null)
        result.AppendLine(string.Format(""Serie name:{0}"", ht.Series.Name));
    lblFooterFlex_Left.Text = result.ToString();

    /*The HitTestInfo returns the data object from the 
    Chart's DataSource Collection*/
    var item = ht.Item as CategoricalPoint;
    if (item != null)
    {
        var result2 = new StringBuilder();
        result2.AppendLine(string.Format(""Name ={0}"", item.Name));
        result2.AppendLine(string.Format(""Sales ={0}"", item.Sales));
        result2.AppendLine(string.Format(""Downloads ={0}"", item.Downloads));
        result2.AppendLine(string.Format(""Expenses ={0}"", item.Expenses));
        lblFooterFlex_Right.Text = result2.ToString();
    }
    else
        lblFooterFlex_Right.Text = string.Empty;
}";

            baseFeature.tbCodeC1.Text = @"
void c1Chart_MouseMove(object sender, MouseEventArgs e)
{
    int g = 0, s = -1, p = -1, d = -1;
    const int MIN_DIST = 5;
    CoordinateFocusEnum focus = CoordinateFocusEnum.XandYCoord;
    ChartGroup grp = c1Chart.ChartGroups[g];
    var result1 = new StringBuilder();
    var result2 = new StringBuilder();

    /*C1Chart requires using multiple Coordinate
    conversion methods to perform HitTesting*/
    ChartRegionEnum region = c1Chart.ChartRegionFromCoord(e.X, e.Y);
    result1.AppendLine(string.Format(""Chart element:{0}"", region));

    if (region == ChartRegionEnum.Legend)
    {
        baseFeature.lblFooterC1_Right.Text = String.Empty;
        if (c1Chart.Legend.SeriesFromCoord(e.X, e.Y, ref g, ref s))
        {
            if (s >= 0)
            {
                string name = grp.ChartData[s].Label;
                result1.AppendLine(string.Format(""Series Name:{0}"",name));
            }
        }
    }
    else
    {
        if (grp.CoordToDataIndex(e.X, e.Y, focus, ref s, ref p, ref d))
        {
            string name = grp.ChartData[s].Label;
            result1.AppendLine(string.Format(""Series Name:{0}"", name));
            if (d < MIN_DIST)
            {
                /*Get the Chart DataSource and then
                * get the Data item at the Point Index 'p'
                */
                var ds = c1Chart.DataSource as ObservableCollection<CategoricalPoint>;
                var item = ds[p];
                result2.AppendLine(string.Format(""Name ={0}"", item.Name));
                result2.AppendLine(string.Format(""Sales ={0}"", item.Sales));
                result2.AppendLine(string.Format(""Downloads ={0}"", item.Downloads));
                result2.AppendLine(string.Format(""Expenses ={0}"", item.Expenses));
                lblFooterC1_Right.Text = result2.ToString();
            }
        }
    }
    lblFooterC1_Left.Text = result1.ToString();
}";
        }
    }
}
