﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using C1.Win.Chart;
using C1.Win.C1Chart;
using FlexChartVsC1Chart.Models;

namespace FlexChartVsC1Chart.Features
{
    public partial class LegendAndTitles : UserControl
    {
        FlexChart flexChart;
        C1Chart c1Chart;
        public LegendAndTitles()
        {
            InitializeComponent();
            baseFeature.UpdateChartType(FlexChartMode.Chart);
            flexChart = baseFeature.flexChart;
            c1Chart = baseFeature.c1Chart;
            SetupFlex();
            SetUpC1();
            SetUpDisplayCode();
        }


        private void SetupFlex()
        {
            /*Series with "Name" set are displayed in Legend automatically
             * No additional steps are needed. 
            */
            flexChart.DataSource = DataSource.RealNumbers;
            flexChart.Header.Content = "FlexChart";
            flexChart.Header.Style.Font = flexChart.Footer.Style.Font = new Font(FontFamily.GenericSansSerif, 20);
            flexChart.Footer.Content = "copyright © GrapeCity, inc.";
            flexChart.BindingX = "XValue";
            flexChart.Series.Clear();
            flexChart.Series.Add(new Series { Binding = "YValue", Name = "Sales" });

            flexChart.ChartType = C1.Chart.ChartType.Column;
            flexChart.Legend.Position = C1.Chart.Position.Bottom;
            flexChart.AxisX.Title = "X-Values";
            flexChart.AxisY.Title = "Y-Values";
        }

        private void SetUpC1()
        {

            c1Chart.DataSource = DataSource.RealNumbers;
            c1Chart.Header.Text = "C1Chart";
            c1Chart.Header.Visible = true;
            c1Chart.Footer.Text = "copyright © GrapeCity, inc.";
            c1Chart.Footer.Visible = true;
            c1Chart.Header.Style.Font = c1Chart.Footer.Style.Font = new Font(FontFamily.GenericSerif, 20);
            c1Chart.ChartGroups[0].ChartData.SeriesList.Clear();

            var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            salesSeries.X.DataField = "XValue";
            salesSeries.Y.DataField = "YValue";
            salesSeries.Label = "Sales";

            c1Chart.Legend.Visible = true;
            c1Chart.Legend.Compass = CompassEnum.South;
            c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.Bar;

            c1Chart.ChartArea.AxisX.Text = "X-Values";
            c1Chart.ChartArea.AxisY.Text = "Y-Values";
        }

        private void SetUpDisplayCode()
        {
            baseFeature.tbCodeFlex.Text = @"
//FlexChart Displays Legend by Default

//Axes Titles
flexChart.AxisX.Title = ""X-Values"";
flexChart.AxisY.Title = ""Y-Values"";";

            baseFeature.tbCodeC1.Text = @"
//C1Chart requires Legend to be made visible explicitly
c1Chart.Legend.Visible = true;

//Axes Titles
c1Chart.ChartArea.AxisX.Text = ""X-Values"";
c1Chart.ChartArea.AxisY.Text = ""Y-Values"";";
        }
    }
}
