﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using C1.Win.Chart;
using C1.Win.C1Chart;
using FlexChartVsC1Chart.Models;

namespace FlexChartVsC1Chart.Features
{
    public partial class LegendToggle : UserControl
    {
        FlexChart flexChart;
        C1Chart c1Chart;
        public LegendToggle()
        {
            InitializeComponent();
            baseFeature.UpdateChartType(FlexChartMode.Chart);
            flexChart = baseFeature.flexChart;
            c1Chart = baseFeature.c1Chart;
            SetupFlex();
            SetUpC1();
            SetUpDisplayCode();
        }


        private void SetupFlex()
        {
            flexChart.DataSource = DataSource.CategoricalData;
            flexChart.Series.Clear();
            flexChart.BindingX = "Name";

            flexChart.Series.Add(new Series { Binding = "Sales", Name = "Sales" });
            flexChart.Series.Add(new Series { Binding = "Downloads", Name = "Downloads" });
            flexChart.Series.Add(new Series { Binding = "Expenses", Name = "Expenses" });

            flexChart.ChartType = C1.Chart.ChartType.Column;
            flexChart.Legend.Position = C1.Chart.Position.Bottom;
            flexChart.LegendToggle = true;

            flexChart.AxisX.Title = "Axis X";
            flexChart.AxisY.Title = "Axis Y";
        }

        private void SetUpC1()
        {

            c1Chart.DataSource = DataSource.CategoricalData;
            c1Chart.ChartGroups[0].ChartData.SeriesList.Clear();

            var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            salesSeries.X.DataField = "Name";
            salesSeries.Y.DataField = "Sales";
            salesSeries.Label = "Sales";

            var downloadsSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            downloadsSeries.X.DataField = "Name";
            downloadsSeries.Y.DataField = "Downloads";
            downloadsSeries.Label = "Downloads";

            var expenseSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            expenseSeries.X.DataField = "Name";
            expenseSeries.Y.DataField = "Expenses";
            expenseSeries.Label = "Expenses";

            c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.Bar;
            c1Chart.Legend.Visible = true;
            c1Chart.Legend.Compass = CompassEnum.South;
            c1Chart.MouseUp += c1Chart_MouseUp;
        }

        void c1Chart_MouseUp(object sender, MouseEventArgs e)
        {
            C1Chart chart = (C1Chart)sender;
            int g = 0, s = -1;

            ChartRegionEnum region = chart.ChartRegionFromCoord(e.X, e.Y);
            if (region.Equals(ChartRegionEnum.Legend))
            {
                C1.Win.C1Chart.Legend leg = chart.Legend;
                if (leg.SeriesFromCoord(e.X, e.Y, ref g, ref s))
                {
                    if (s >= 0 && e.Button.Equals(MouseButtons.Left))
                            ToggleSeriesDisplay(s);
                }
            }
        }


        private void ToggleSeriesDisplay(int s)
        {
            ChartDataSeries ser = c1Chart.ChartGroups[0].ChartData[s];
            if (ser.Display.Equals(SeriesDisplayEnum.Show))
                ser.Display = SeriesDisplayEnum.Hide;
            else
                ser.Display = SeriesDisplayEnum.Show;
        }

        private void SetUpDisplayCode()
        {
            baseFeature.tbCodeFlex.Text = @"
//To enable Legend Toggling in FlexChart
flexChart.LegendToggle = true;";

            baseFeature.tbCodeC1.Text = @"
//In the MouseUp Event of C1Chart capture the series index that is clicked
//and then modify the series visibility accordingly.
void c1Chart_MouseUp(object sender, MouseEventArgs e)
{
    C1Chart chart = (C1Chart)sender;
    int g = 0, s = -1;

    ChartRegionEnum region = chart.ChartRegionFromCoord(e.X, e.Y);
    if(region.Equals(ChartRegionEnum.Legend))
    {
            C1.Win.C1Chart.Legend leg = chart.Legend;
            if (leg.SeriesFromCoord(e.X, e.Y, ref g, ref s))
            {
                    if (s >= 0 && e.Button.Equals(MouseButtons.Flex))
                        ToggleSeriesDisplay(s);
            }
    }
}

private void ToggleSeriesDisplay(int s)
{
    ChartDataSeries ser = c1Chart.ChartGroups[0].ChartData[s];
    if (ser.Display.Equals(SeriesDisplayEnum.Show))
            ser.Display = SeriesDisplayEnum.Hide;
    else
            ser.Display = SeriesDisplayEnum.Show;
}";
        }
    }
}
