﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using C1.Chart;
using C1.Win.Chart;
using C1.Win.C1Chart;
using FlexChartVsC1Chart.Models;

namespace FlexChartVsC1Chart.Features
{
    public partial class MixedChartTypes : UserControl
    {
        FlexChart flexChart;
        C1Chart c1Chart;
        public MixedChartTypes()
        {
            InitializeComponent();
            baseFeature.UpdateChartType(FlexChartMode.Chart);
            flexChart = baseFeature.flexChart;
            c1Chart = baseFeature.c1Chart;
            SetupFlex();
            SetUpC1();
            SetUpDisplayCode();
        }


        private void SetupFlex()
        {

            flexChart.DataSource = DataSource.CategoricalData;
            flexChart.BindingX = "Name";

            flexChart.Series.Clear();

            var salesSeries = new Series { Binding = "Sales", Name = "Sales"};
            salesSeries.ChartType = ChartType.Column;
            flexChart.Series.Add(salesSeries);

            var expensesSeries  = new Series { Binding = "Expenses", Name = "Expenses" }; 
            expensesSeries.ChartType = ChartType.LineSymbols;
            flexChart.Series.Add(expensesSeries);
            expensesSeries.AxisY = new C1.Win.Chart.Axis { Position = Position.Right};

            flexChart.Legend.Position = Position.Bottom;
            flexChart.AxisX.Title = "Axis X";
            flexChart.AxisY.Title = "Axis Y";
            flexChart.AxisY.Min = 0;
            flexChart.AxisY.AxisLine = true;

        }

        private void SetUpC1()
        {

            c1Chart.DataSource = DataSource.CategoricalData;
            c1Chart.ChartGroups[0].ChartData.SeriesList.Clear();

            var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            salesSeries.X.DataField = "Name";
            salesSeries.Y.DataField = "Sales";
            salesSeries.Label = "Sales";

            var expenseSeries = c1Chart.ChartGroups[1].ChartData.SeriesList.AddNewSeries();
            expenseSeries.X.DataField = "Name";
            expenseSeries.Y.DataField = "Expenses";
            expenseSeries.Label = "Expenses";

            //C1Chart can combine only 2 ChartTypes
            c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.Bar;
            c1Chart.ChartGroups[1].ChartType = Chart2DTypeEnum.XYPlot;

            c1Chart.Legend.Visible = true;
            c1Chart.Legend.Compass = CompassEnum.South;
            c1Chart.ChartArea.AxisY.Min = 0;

        }

        private void SetUpDisplayCode()
        {
            baseFeature.tbCodeFlex.Text = @"
var salesSeries = new Series { Binding = ""Sales"", Name = ""Sales""};
salesSeries.ChartType = ChartType.Column;
flexChart.Series.Add(salesSeries);

var expensesSeries  = new Series { Binding = ""Expenses"", Name = ""Expenses"" }; 
expensesSeries.ChartType = ChartType.LineSymbols;
flexChart.Series.Add(expensesSeries);";

            baseFeature.tbCodeC1.Text = @"
var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
salesSeries.X.DataField = ""Name"";
salesSeries.Y.DataField = ""Sales"";
salesSeries.Label = ""Sales"";

var expenseSeries = c1Chart.ChartGroups[1].ChartData.SeriesList.AddNewSeries();
expenseSeries.X.DataField = ""Name"";
expenseSeries.Y.DataField = ""Expenses"";
expenseSeries.Label = ""Expenses"";

c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.Bar;
c1Chart.ChartGroups[1].ChartType = Chart2DTypeEnum.XYPlot;";
        }
    }
}
