﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using C1.Win.Chart;
using C1.Win.C1Chart;
using FlexChartVsC1Chart.Models;

namespace FlexChartVsC1Chart.Features
{
    public partial class Selection : UserControl
    {
        FlexChart flexChart;
        C1Chart c1Chart;
        int selectedIndex = -1;
        List<Color> clrs;
        public Selection()
        {
            InitializeComponent();
            baseFeature.UpdateChartType(FlexChartMode.Chart);
            flexChart = baseFeature.flexChart;
            c1Chart = baseFeature.c1Chart;
            SetupFlex();
            SetUpC1();
            SetUpDisplayCode();
        }


        private void SetupFlex()
        {
            flexChart.DataSource = DataSource.CategoricalData;
            flexChart.Series.Clear();
            flexChart.BindingX = "Name";

            flexChart.Series.Add(new Series { Binding = "Sales", Name = "Sales" });
            flexChart.Series.Add(new Series { Binding = "Downloads", Name = "Downloads" });
            flexChart.Series.Add(new Series { Binding = "Expenses", Name = "Expenses" });

            flexChart.ChartType = C1.Chart.ChartType.Line;
            flexChart.Legend.Position = C1.Chart.Position.Bottom;

            flexChart.AxisX.Title = "Axis X";
            flexChart.AxisY.Title = "Axis Y";

            flexChart.SelectionMode = C1.Chart.ChartSelectionMode.Series;
            flexChart.SelectionStyle.Fill = new SolidBrush(Color.Red);
            flexChart.SelectionStyle.StrokeWidth = 2;
        }

        private void SetUpC1()
        {

            c1Chart.DataSource = DataSource.CategoricalData;
            c1Chart.ChartGroups[0].ChartData.SeriesList.Clear();
            clrs = new List<Color>();


            var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            salesSeries.X.DataField = "Name";
            salesSeries.Y.DataField = "Sales";
            salesSeries.Label = "Sales";
            clrs.Add(salesSeries.LineStyle.Color);


            var downloadsSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            downloadsSeries.X.DataField = "Name";
            downloadsSeries.Y.DataField = "Downloads";
            downloadsSeries.Label = "Downloads";
            clrs.Add(downloadsSeries.LineStyle.Color);

            var expenseSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            expenseSeries.X.DataField = "Name";
            expenseSeries.Y.DataField = "Expenses";
            expenseSeries.Label = "Expenses";
            clrs.Add(expenseSeries.LineStyle.Color);

            salesSeries.SymbolStyle.Shape = downloadsSeries.SymbolStyle.Shape = expenseSeries.SymbolStyle.Shape = SymbolShapeEnum.None; 

            c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.XYPlot;
            c1Chart.Legend.Compass = CompassEnum.South;
            c1Chart.Legend.Visible = true;
            c1Chart.Click += c1Chart_Click;
        }

        void c1Chart_Click(object sender, EventArgs e)
        {
            Point p = Control.MousePosition;

            // Convert to client coordinates
            p = c1Chart.PointToClient(p);

            int si = -1; int d = -1;

            // Find the distance
            if (c1Chart.ChartGroups[0].CoordToSeriesIndex(p.X, p.Y, PlotElementEnum.Series, ref si, ref d))
            {
                if (d <= 3) // if close enough
                {
                    if (si != selectedIndex) // Another index
                    {
                        if (selectedIndex != -1)
                        {
                            // Change series color and width to the default
                            ChartDataSeries ds = c1Chart.ChartGroups[0].ChartData[selectedIndex];
                            ds.LineStyle.Color = clrs[selectedIndex];
                            ds.LineStyle.Thickness = 1;
                        }

                        selectedIndex = si;
                        if (selectedIndex != -1)
                        {
                            // Change series color and width to indicate selection
                            ChartDataSeries ds = c1Chart.ChartGroups[0].ChartData[selectedIndex];
                            ds.LineStyle.Color = Color.Red;
                            ds.LineStyle.Thickness = 2;
                        }
                    }
                }
            }
        }

        private void SetUpDisplayCode()
        {
            baseFeature.tbCodeFlex.Text = @"
//FlexChart has in-built Series/DataPoint selection support
flexChart.SelectionMode = C1.Chart.ChartSelectionMode.Series;
flexChart.SelectionStyle.Fill = new SolidBrush(Color.Red);
flexChart.SelectionStyle.StrokeWidth = 2.5f;";

            baseFeature.tbCodeC1.Text = @"
//C1Chart requires certain extra efforts to showcase selection

//Store the default colors of the series in a list
List<Color> clrs = new List<Color>();
clrs.Add(salesSeries.LineStyle.Color);
clrs.Add(downloadsSeries.LineStyle.Color);
clrs.Add(expenseSeries.LineStyle.Color);

//Get the series tapped via mouse position in the C1Chart click handler
void c1Chart_Click(object sender, EventArgs e)
{
        Point p = Control.MousePosition;

        // Convert to client coordinates
        p = c1Chart.PointToClient(p);

        int si = -1; int d = -1;

        // Find the distance
        if (c1Chart.ChartGroups[0].CoordToSeriesIndex(p.X, p.Y, PlotElementEnum.Series, ref si, ref d))
        {
            if (d <= 3) // if close enough
            {
                if (si != selectedIndex) // Another index
                {
                    if (selectedIndex != -1)
                    {
                        // Change series color and width to the default
                        ChartDataSeries ds = c1Chart.ChartGroups[0].ChartData[selectedIndex];
                        ds.LineStyle.Color = clrs[selectedIndex];
                        ds.LineStyle.Thickness = 1;
                    }

                    selectedIndex = si;
                    if (selectedIndex != -1)
                    {
                        // Change series color and width to indicate selection
                        ChartDataSeries ds = c1Chart.ChartGroups[0].ChartData[selectedIndex];
                        ds.LineStyle.Color = Color.Red;
                        ds.LineStyle.Thickness = 2;
                    }
                }
            }
        }
}";
        }
    }
}
