﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using C1.Win.Chart;
using C1.Win.C1Chart;
using FlexChartVsC1Chart.Models;

namespace FlexChartVsC1Chart.Features
{
    public partial class SplineArea : UserControl
    {
        FlexChart flexChart;
        C1Chart c1Chart;
        public SplineArea()
        {
            InitializeComponent(); baseFeature.UpdateChartType(FlexChartMode.Chart);
            flexChart = baseFeature.flexChart;
            c1Chart = baseFeature.c1Chart;
            SetupFlex();
            SetUpC1();
            SetUpDisplayCode();
        }


        private void SetupFlex()
        {
            flexChart.DataSource = DataSource.CategoricalData;
            flexChart.Series.Clear();
            flexChart.BindingX = "Name";

            flexChart.Series.Add(new Series { Binding = "Sales", Name = "Sales" });
            flexChart.Series.Add(new Series { Binding = "Downloads", Name = "Downloads" });
            flexChart.Series.Add(new Series { Binding = "Expenses", Name = "Expenses" });

            flexChart.ChartType = C1.Chart.ChartType.SplineArea;
            flexChart.Legend.Position = C1.Chart.Position.Bottom;

            flexChart.AxisX.Title = "Axis X";
            flexChart.AxisY.Title = "Axis Y";
        }

        private void SetUpC1()
        {

            c1Chart.DataSource = DataSource.CategoricalData;
            c1Chart.ChartGroups[0].ChartData.SeriesList.Clear();

            var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            salesSeries.X.DataField = "Name";
            salesSeries.Y.DataField = "Sales";
            salesSeries.Label = "Sales";

            var downloadsSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            downloadsSeries.X.DataField = "Name";
            downloadsSeries.Y.DataField = "Downloads";
            downloadsSeries.Label = "Downloads";

            var expenseSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            expenseSeries.X.DataField = "Name";
            expenseSeries.Y.DataField = "Expenses";
            expenseSeries.Label = "Expenses";

            c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.Area;
            c1Chart.Legend.Visible = true;
            c1Chart.Legend.Compass = CompassEnum.South;

            foreach (ChartDataSeries ds in c1Chart.ChartGroups[0].ChartData.SeriesList)
            {
                ds.FitType = FitTypeEnum.Spline;
                ds.FillStyle.Alpha = 128;
            }

        }

        private void SetUpDisplayCode()
        {
            baseFeature.tbCodeFlex.Text = @"
flexChart.ChartType = C1.Chart.ChartType.SplineArea;
";

            baseFeature.tbCodeC1.Text = @"
foreach (ChartDataSeries ds in c1Chart.ChartGroups[0].ChartData.SeriesList)
{
        ds.FitType = FitTypeEnum.Spline;
        //To get the transparent effect while rendering 
        ds.FillStyle.Alpha = 128;
}";
        }
    }
}
