﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using C1.Win.Chart;
using C1.Win.C1Chart;
using FlexChartVsC1Chart.Models;


namespace FlexChartVsC1Chart.Features
{
    public partial class Tooltips : UserControl
    {
        FlexChart flexChart;
        C1Chart c1Chart;
        public Tooltips()
        {
            InitializeComponent();
            baseFeature.UpdateChartType(FlexChartMode.Chart);
            flexChart = baseFeature.flexChart;
            c1Chart = baseFeature.c1Chart;
            SetupFlex();
            SetUpC1();
            SetUpDisplayCode();
        }


        private void SetupFlex()
        {
            flexChart.DataSource = DataSource.CategoricalData;
            flexChart.BindingX = "Name";

            flexChart.Series.Clear();
            flexChart.Series.Add(new Series { Binding = "Sales", Name = "Sales" });
            flexChart.Series.Add(new Series { Binding = "Downloads", Name = "Downloads" });
            flexChart.Series.Add(new Series { Binding = "Expenses", Name = "Expenses" });
            flexChart.ChartType = C1.Chart.ChartType.Column;
            flexChart.Legend.Position = C1.Chart.Position.Bottom;
            flexChart.AxisY.Min = 0;
            flexChart.AxisX.Title = "Axis X";
            flexChart.AxisY.Title = "Axis Y";
            
            //Setup Tooltip content
            flexChart.ToolTip.Content = "{seriesName}\nXValue:{x}\nYValue:{y}";
        }

        private void SetUpC1()
        {

            c1Chart.DataSource = DataSource.CategoricalData;
            c1Chart.ChartGroups[0].ChartData.SeriesList.Clear();

            var salesSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            salesSeries.X.DataField = "Name";
            salesSeries.Y.DataField = "Sales";
            salesSeries.Label = "Sales";

            var downloadsSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            downloadsSeries.X.DataField = "Name";
            downloadsSeries.Y.DataField = "Downloads";
            downloadsSeries.Label = "Downloads";

            var expenseSeries = c1Chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            expenseSeries.X.DataField = "Name";
            expenseSeries.Y.DataField = "Expenses";
            expenseSeries.Label = "Expenses";

            c1Chart.ChartGroups[0].ChartType = Chart2DTypeEnum.Bar;
            c1Chart.Legend.Visible = true;
            c1Chart.Legend.Compass = CompassEnum.South;
            

            //Enable Tooltips to display 
            c1Chart.ToolTip.Enabled = true;

            //Setup Tooltip content
            c1Chart.ShowTooltip += (s, a) =>
                {
                    var item = DataSource.CategoricalData[a.PointIndex];
                    switch (a.SeriesIndex)
                    {
                        case 0: a.TooltipText = string.Format("{0}\nXVaue:{1}\nYValue:{2}", c1Chart.ChartGroups[0].ChartData.SeriesList[a.SeriesIndex].Label, item.Name, item.Sales);
                            break;
                        case 1: a.TooltipText = string.Format("{0}\nXVaue:{1}\nYValue:{2}", c1Chart.ChartGroups[0].ChartData.SeriesList[a.SeriesIndex].Label, item.Name, item.Downloads);
                            break;
                        case 2: a.TooltipText = string.Format("{0}\nXVaue:{1}\nYValue:{2}", c1Chart.ChartGroups[0].ChartData.SeriesList[a.SeriesIndex].Label, item.Name, item.Expenses);
                            break;
                    }
                };
        }

        private void SetUpDisplayCode()
        {
            baseFeature.tbCodeFlex.Text = @"
flexChart.ToolTip.Content = ""{seriesName}\nXValue:{x}\nYValue:{y}""";

            baseFeature.tbCodeC1.Text = @"
//Enable Tooltips to display 
c1Chart.ToolTip.Enabled = true;

//Setup Tooltip content
c1Chart.ShowTooltip += (s, a) =>
{
    var item = DataSource.CategoricalData[a.PointIndex];
    switch (a.SeriesIndex)
    {
        case 0: a.TooltipText = string.Format(""{0}\nXVaue:{1}\nYValue:{2}"", c1Chart.ChartGroups[0].ChartData.SeriesList[a.SeriesIndex].Label, item.Name, item.Sales);
            break;
        case 1: a.TooltipText = string.Format(""{0}\nXVaue:{1}\nYValue:{2}"", c1Chart.ChartGroups[0].ChartData.SeriesList[a.SeriesIndex].Label, item.Name, item.Downloads);
            break;
        case 2: a.TooltipText = string.Format(""{0}\nXVaue:{1}\nYValue:{2}"", c1Chart.ChartGroups[0].ChartData.SeriesList[a.SeriesIndex].Label, item.Name, item.Expenses);
            break;
    }
};";
        }
    }
}
