﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using FlexChartVsC1Chart.Resources;

namespace FlexChartVsC1Chart
{
    public partial class MainForm : Form
    {
        #region const
        Color MENU_BACK_COLOR = System.Drawing.Color.FromArgb(249, 249, 249);
        Color MENU_ONOVER_COLOR = System.Drawing.Color.FromArgb(21, 164, 250);
        Color MENU_SELECTED_COLOR = System.Drawing.Color.FromArgb(230, 230, 230);
        int MENU_BUTTON_HEIGHT = 30;
        #endregion

        #region fields
        List<Image> _menuButtonImagesClicked = new List<Image>();
        List<Image> _menuButtonImages = new List<Image>();
        Dictionary<string, KeyValuePair<string, string>> featureMap = new Dictionary<string, KeyValuePair<string, string>>()
        {
          //{"BUTTON TITLE", new KeyValuePair<string,string>( "ClassName", "Parent BUTTON TITLE" ) }
           { AppResources.GettingStartedMenuItem, new KeyValuePair<string,string>( "GettingStarted", "null" ) }
          ,{ AppResources.ChartTypesMenuItem, new KeyValuePair<string,string>( "ChartTypes", "null") }
          ,{AppResources.ScatterMenuItem,new KeyValuePair<string,string>( "Scatter", AppResources.ChartTypesMenuItem)}
          ,{AppResources.SplineMenuItem,new KeyValuePair<string,string>( "Spline", AppResources.ChartTypesMenuItem)}
          ,{AppResources.SplineAreaMenuItem,new KeyValuePair<string,string>( "SplineArea", AppResources.ChartTypesMenuItem)}
          ,{AppResources.HLOCMenuItem,new KeyValuePair<string,string>( "FinancialCharts", AppResources.ChartTypesMenuItem)}
          ,{AppResources.MixedChartTypesMenuItem, new KeyValuePair<string,string>( "MixedChartTypes" , "null")}
          ,{AppResources.LegendAndTitleMenuItem, new KeyValuePair<string,string>( "LegendAndTitles" , "null")}
          ,{AppResources.TooltipsMenuItem, new KeyValuePair<string,string>( "Tooltips", "null") }
          ,{AppResources.HitTestMenuItem,new KeyValuePair<string,string>( "HitTest", "null")}
          ,{AppResources.DataLabelsMenuItem,new KeyValuePair<string,string>( "DataLabels", "null")}
          ,{AppResources.DynamicChartsMenuItem,new KeyValuePair<string,string>( "DynamicCharts", "null")}
          ,{AppResources.SelectionMenuItem, new KeyValuePair<string,string>( "Selection" , "null")}
          ,{AppResources.LegendToggleMenuItem,new KeyValuePair<string,string>( "LegendToggle", "null")}
          ,{AppResources.PieChartsMenuItem,new KeyValuePair<string,string>( "PieCharts", "null")}
        };
        private int oldHeight = -1;
        private int oldWidth = -1;
        #endregion
        public MainForm()
        {
            InitializeComponent();
            this.Text = AppResources.MainFormTitle;
            LoadFeatures();
        }

        private void LoadFeatures()
        {
            pnlFeatureList.BackColor = MENU_BACK_COLOR;
            var top = 20;
            foreach (var item in featureMap.Reverse())
            {
                ItemHelper itemHelper = new ItemHelper();
                itemHelper.IsExpanded = false;
                if (featureMap.Count(d => d.Value.Value == item.Key) > 0)
                {
                    itemHelper.IsExpanded = true;
                    itemHelper.IsParent = true;
                }
                else
                {
                    itemHelper.IsParent = false;
                }
                if (item.Value.Value != "null")
                {
                    itemHelper.IsChild = true;
                }
                else
                {
                    itemHelper.IsChild = false;
                }
                var newButton = new Button()
                {
                    Text = item.Key,
                    TextAlign = ContentAlignment.MiddleLeft,
                    Width = pnlFeatureList.Width - 2,
                    Height = MENU_BUTTON_HEIGHT,
                    FlatStyle = FlatStyle.Flat,
                    Left = 1,
                    Tag = itemHelper,
                    Dock = DockStyle.Top
                };
                newButton.Padding = new Padding(15, 0, 0, 0);
                newButton.Click += featureButtonClick;
                pnlFeatureList.Controls.Add(newButton);

                // Initialize button style image
                Image _menuButtonImageClicked = new Bitmap(pnlFeatureList.Width + 15, MENU_BUTTON_HEIGHT + 1);
                Image _menuButtonImage = new Bitmap(pnlFeatureList.Width + 15, MENU_BUTTON_HEIGHT + 1);
                Image _menuButtonImageHover = new Bitmap(pnlFeatureList.Width + 15, MENU_BUTTON_HEIGHT + 1);
                _menuButtonImageClicked.Tag = item.Key;
                _menuButtonImage.Tag = item.Key;
                if (itemHelper.IsParent)
                {
                    newButton.Font = new Font("Segoe UI", 10, FontStyle.Bold);
                    newButton.ForeColor = Color.FromArgb(64, 64, 64);
                    newButton.FlatAppearance.BorderSize = 0;
                    newButton.FlatAppearance.MouseOverBackColor = MENU_ONOVER_COLOR;
                    using (Graphics g = Graphics.FromImage(_menuButtonImageClicked))
                    {
                        g.Clear(MENU_ONOVER_COLOR);
                        Pen pen = new Pen(new SolidBrush(MENU_BACK_COLOR));
                        pen.Width = 2.0F;
                        g.DrawLine(pen, pnlFeatureList.Width - 2 - 24, 18, pnlFeatureList.Width - 2 - 18, 12);
                        g.DrawLine(pen, pnlFeatureList.Width - 2 - 18, 12, pnlFeatureList.Width - 2 - 12, 18);
                        using (var border = new Pen(new SolidBrush(Color.DarkGray)))
                        {
                            g.DrawLine(border, -1, 0, -1, newButton.Height - 1);
                            g.DrawLine(border, newButton.Width - 2, 0, newButton.Width - 2, newButton.Height - 1);
                        }
                    }
                    using (Graphics g = Graphics.FromImage(_menuButtonImage))
                    {
                        g.Clear(MENU_BACK_COLOR);
                        Pen pen = new Pen(new SolidBrush(Color.Black));
                        pen.Width = 2.0F;
                        g.DrawLine(pen, pnlFeatureList.Width - 2 - 24, 12, pnlFeatureList.Width - 2 - 18, 18);
                        g.DrawLine(pen, pnlFeatureList.Width - 2 - 18, 18, pnlFeatureList.Width - 2 - 12, 12);
                        using (var border = new Pen(new SolidBrush(Color.DarkGray)))
                        {
                            g.DrawLine(border, 0, 0, 0, newButton.Height - 1);
                            g.DrawLine(border, newButton.Width - 2, 0, newButton.Width - 2, newButton.Height - 1);
                        }
                    }
                }
                else if (itemHelper.IsChild)
                {
                    newButton.Font = new Font("Segoe UI", 10, FontStyle.Regular);
                    newButton.ForeColor = Color.FromArgb(64, 64, 64);
                    newButton.BackColor = MENU_SELECTED_COLOR;
                    newButton.FlatAppearance.BorderSize = 0;
                    newButton.FlatAppearance.MouseOverBackColor = MENU_ONOVER_COLOR;
                    newButton.Visible = true;
                    using (Graphics g = Graphics.FromImage(_menuButtonImage))
                    {
                        g.Clear(MENU_SELECTED_COLOR);
                        using (var border = new Pen(new SolidBrush(Color.DarkGray)))
                        {
                            g.DrawLine(border, 0, 0, 0, newButton.Height - 1);
                            g.DrawLine(border, newButton.Width - 2, 0, newButton.Width - 2, newButton.Height - 1);
                        }
                    }
                    using (Graphics g = Graphics.FromImage(_menuButtonImageClicked))
                    {
                        g.Clear(MENU_SELECTED_COLOR);
                        using (var border = new Pen(new SolidBrush(Color.DarkGray)))
                        {
                            g.DrawLine(border, 0, 0, 0, newButton.Height - 1);
                            g.DrawLine(border, newButton.Width - 2, 0, newButton.Width - 2, newButton.Height - 1);
                        }

                    }
                }
                else
                {
                    newButton.Font = new Font("Segoe UI", 10, FontStyle.Bold);
                    newButton.ForeColor = Color.FromArgb(64, 64, 64);
                    newButton.FlatAppearance.BorderSize = 0;
                    newButton.FlatAppearance.MouseOverBackColor = MENU_ONOVER_COLOR;

                    using (Graphics g = Graphics.FromImage(_menuButtonImage))
                    {
                        using (var border = new Pen(new SolidBrush(Color.DarkGray)))
                        {
                            g.DrawLine(border, 0, 0, 0, newButton.Height - 1);
                            g.DrawLine(border, newButton.Width - 2, 0, newButton.Width - 2, newButton.Height - 1);
                        }
                    }
                    using (Graphics g = Graphics.FromImage(_menuButtonImageClicked))
                    {
                        g.Clear(MENU_ONOVER_COLOR);
                        using (var border = new Pen(new SolidBrush(Color.DarkGray)))
                        {
                            g.DrawLine(border, 0, 0, 0, newButton.Height - 1);
                            g.DrawLine(border, newButton.Width - 2, 0, newButton.Width - 2, newButton.Height - 1);
                        }

                    }
                }
                _menuButtonImagesClicked.Add(_menuButtonImageClicked);
                _menuButtonImages.Add(_menuButtonImage);
            }
        }

        private void featureButtonClick(object sender, EventArgs e)
        {
            var clickedButton = (sender as Button);
            panelMainBody.Controls.Clear();
            var str = clickedButton.Text;
            string nameSpace = "FlexChartVsC1Chart.Features." + featureMap.First(kp => kp.Key == str).Value.Key;
            Type sampleType = Type.GetType(nameSpace, true);
            Control newControl = (Control)Activator.CreateInstance(sampleType);
            newControl.Dock = DockStyle.Fill;
            panelMainBody.Controls.Add(newControl);

            ButtonToggling(clickedButton);
        }

        private void ButtonToggling(Button clickedButton)
        {
            if (((ItemHelper)clickedButton.Tag).IsParent)
            {
                ((ItemHelper)clickedButton.Tag).IsExpanded = !((ItemHelper)clickedButton.Tag).IsExpanded;
            }

            // Paint selection button color
            foreach (Button item in pnlFeatureList.Controls)
            {
                if (((ItemHelper)item.Tag).IsParent)
                {
                    if (!((ItemHelper)clickedButton.Tag).IsChild)
                    {
                        item.Image = _menuButtonImages.First(btn => btn.Tag.ToString() == item.Text);
                        item.ForeColor = Color.FromArgb(64, 64, 64);
                    }
                }
                else if (((ItemHelper)item.Tag).IsChild)
                {
                    item.Image = _menuButtonImages.First(btn => btn.Tag.ToString() == item.Text);
                    item.ForeColor = Color.FromArgb(64, 64, 64);
                    if (((ItemHelper)clickedButton.Tag).IsParent)
                    {
                        if (((ItemHelper)clickedButton.Tag).IsExpanded)
                        {
                            item.Visible = true;
                        }
                        else
                        {
                            item.Visible = false;
                        }
                    }
                }
                else
                {
                    item.Image = _menuButtonImages.First(btn => btn.Tag.ToString() == item.Text);
                    item.ForeColor = Color.FromArgb(64, 64, 64);
                }
            }
            if (((ItemHelper)clickedButton.Tag).IsParent)
            {
                if (((ItemHelper)clickedButton.Tag).IsExpanded)
                {
                    clickedButton.ForeColor = MENU_BACK_COLOR;
                    clickedButton.Image = _menuButtonImagesClicked.First(btn => btn.Tag.ToString() == clickedButton.Text);
                }
                else
                {
                    clickedButton.ForeColor = Color.FromArgb(64, 64, 64);
                    clickedButton.Image = _menuButtonImages.First(btn => btn.Tag.ToString() == clickedButton.Text);
                }

            }
            else if (((ItemHelper)clickedButton.Tag).IsChild)
            {
                clickedButton.ForeColor = MENU_ONOVER_COLOR;
                clickedButton.BackColor = MENU_SELECTED_COLOR;
                clickedButton.Image = _menuButtonImagesClicked.First(btn => btn.Tag.ToString() == clickedButton.Text);
            }
            else
            {
                clickedButton.ForeColor = MENU_BACK_COLOR;
                clickedButton.Image = _menuButtonImagesClicked.First(btn => btn.Tag.ToString() == clickedButton.Text);
                foreach (Button item in pnlFeatureList.Controls)
                {
                    if (((ItemHelper)clickedButton.Tag).IsParent)
                    {
                        ((ItemHelper)item.Tag).IsExpanded = false;
                    }
                    if (((ItemHelper)item.Tag).IsChild)
                    {
                        item.Visible = false;
                    }
                }
            }
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            // Open first link
            if (pnlFeatureList.Controls[pnlFeatureList.Controls.Count - 1] is Button)
                (pnlFeatureList.Controls[pnlFeatureList.Controls.Count - 1] as Button).PerformClick();
        }

        private void pnlFeatureList_Paint(object sender, PaintEventArgs e)
        {
            using (var pen = new Pen(new SolidBrush(Color.DarkGray)))
            {
                e.Graphics.DrawRectangle(pen, 1, 0, pnlFeatureList.Width - 2, pnlFeatureList.Height - 1);
                oldWidth = pnlFeatureList.Width - 1;
                oldHeight = pnlFeatureList.Height - 1;
            }
        }

        private void MainForm_Resize(object sender, EventArgs e)
        {
            this.pnlFeatureList.Refresh();
            var h = this.Height;
            var offSet = h * 0.9;
            var padding = (int) (h - offSet)/2 ;
            this.panelMainBody.Padding = new Padding(0, 0, 0, padding);
        }
    }

    public class ItemHelper
    {
        public KeyValuePair<string, KeyValuePair<string, string>> Item;
        public bool IsParent;
        public bool IsChild;
        public bool IsExpanded;
    }
}
