﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;

namespace FlexChartVsC1Chart.Models
{
    public class DataSource
    {
        public static ObservableCollection<CategoricalPoint> CategoricalData
        {
            get{return GetCategoricalData();}
        }
        public static ObservableCollection<BubblePoint> BubbleChartData
        {
            get { return GetBubbleChartData(); }
        }
        public static ObservableCollection<FinancialPoint> FinancialChartData
        {
            get { return GetFinancialData(); }
        }
        public static ObservableCollection<NumericPoint> NumericData
        {
            get { return GetNumericData(); }
        }
        public static ObservableCollection<NumericPoint> RealNumbers
        {
            get { return GetRealNumbersData(); }
        }
        public static ObservableCollection<DateTimePoint> DateTimeData
        {
            get { return GetDateTimeData(); }
        }
        
        private static ObservableCollection<CategoricalPoint> GetCategoricalData()
        {
            ObservableCollection<CategoricalPoint> categoricalData = new ObservableCollection<CategoricalPoint>();
            var DayNames = "Mon,Tues,Wed,Thurs,Fri".Split(',');
            var salesData = new[] { 5000, 8500, 7000, 6500, 12000 };
            var downloadsData = new[] { 6000, 7500, 12000, 5800, 11000 };
            var expensesData = new[] { 15000, 18000, 15500, 18500, 9500 };
            for (int i = 0; i < 5; i++)
            {
                CategoricalPoint temp = new CategoricalPoint();
                temp.Name = DayNames[i];
                temp.Sales = salesData[i];
                temp.Downloads = downloadsData[i];
                temp.Expenses = expensesData[i];
                categoricalData.Add(temp);
            }
            return categoricalData;
        }
        private static ObservableCollection<BubblePoint> GetBubbleChartData()
        {
            ObservableCollection<BubblePoint> _bubbleData = new ObservableCollection<BubblePoint>();
            var name = new[] { "US", "UK", "Greece", "India", "Japan" };
            var xVal = new[] { 14, 20, 17, 22, 55 };
            var yVal = new[] { 800, 400, 350, 250, 600 };
            var size = new[] { 25, 5, 15, 65,80 };
            for (var j = 0; j < 5; j++)
            {
                BubblePoint b = new BubblePoint();
                b.Name = name[j];
                b.XValue = j+1;
                b.YValue = yVal[j];
                b.Size = size[j];
                _bubbleData.Add(b);
            }
            return _bubbleData;
        }
        private static ObservableCollection<FinancialPoint> GetFinancialData()
        {
            ObservableCollection<FinancialPoint> _financialData = new ObservableCollection<FinancialPoint>();
            var high = new[] { 514, 513, 515, 516, 528 };
            var low = new[] { 505, 507, 510, 511, 514 };
            var open = new[] { 511, 507, 512, 513, 515 };
            var close = new[] { 506, 512, 511, 515, 525 };
            var dateString = new[] { "1st Dec", "2nd Dec", "3rd Dec", "4th Dec", "5th Dec" };
            for (int j = 0; j < 5; j++)
            {
                FinancialPoint fin = new FinancialPoint();
                fin.Date = dateString[j];
                fin.High = high[j];
                fin.Low = low[j];
                fin.Open = open[j];
                fin.Close = close[j];
                _financialData.Add(fin);
            }
            return _financialData;
        }
        private static ObservableCollection<NumericPoint> GetNumericData()
        {
            ObservableCollection<NumericPoint> _numericData = new ObservableCollection<NumericPoint>();
            Random r=new Random();
            for (int i = 0; i <= 5; i++)
            {
                NumericPoint temp = new NumericPoint();
                temp.XValue = i*10;
                temp.YValue = Math.Round( r.NextDouble() * 20000);
                _numericData.Add(temp);
            }
            return _numericData;
        }
        private static ObservableCollection<NumericPoint> GetRealNumbersData()
        {
            ObservableCollection<NumericPoint> _realNumbersData = new ObservableCollection<NumericPoint>();
            Random r = new Random();
            bool isNegative = false;
            for (int i = -50; i <= 50; i++)
            {
                isNegative = r.NextDouble() > 0.5;
                NumericPoint temp = new NumericPoint();
                temp.XValue = i;
                temp.YValue = isNegative ? -1  * r.NextDouble() * 1000 :  r.NextDouble() * 1000; 
                _realNumbersData.Add(temp);
            }
            return _realNumbersData;
        }
        private static ObservableCollection<DateTimePoint> GetDateTimeData()
        {
            ObservableCollection<DateTimePoint> _dateTiemData = new ObservableCollection<DateTimePoint>();
            Random r = new Random();
            DateTime today = DateTime.Today;
            for (int i = 1; i <= 10; i++)
            {
                DateTimePoint temp = new DateTimePoint();
                temp.XValue = today.AddDays(5);
                temp.YValue = r.NextDouble() * 20000;
                _dateTiemData.Add(temp);
                today = temp.XValue;
            }
            return _dateTiemData;
        }
    
    }
}